﻿using System;
using System.Collections.Generic;
using Microsoft.EntityFrameworkCore;

namespace PracMedic.Models;

public partial class PracMedicContext : DbContext
{
    public PracMedicContext()
    {
    }

    public PracMedicContext(DbContextOptions<PracMedicContext> options)
        : base(options)
    {
    }

    public virtual DbSet<Anamneza> Anamnezas { get; set; }

    public virtual DbSet<Dekur> Dekurs { get; set; }

    public virtual DbSet<Doktor> Doktors { get; set; }

    public virtual DbSet<HistorieLeku> HistorieLekus { get; set; }

    public virtual DbSet<HistorieReceptu> HistorieReceptus { get; set; }

    public virtual DbSet<Leky> Lekies { get; set; }

    public virtual DbSet<Neschopenka> Neschopenkas { get; set; }

    public virtual DbSet<Objednani> Objednanis { get; set; }

    public virtual DbSet<Ockovani> Ockovanis { get; set; }

    public virtual DbSet<Pacient> Pacients { get; set; }

    public virtual DbSet<Pracoviste> Pracovistes { get; set; }

    public virtual DbSet<VystaveniReceptu> VystaveniReceptus { get; set; }

    protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
#warning To protect potentially sensitive information in your connection string, you should move it out of source code. You can avoid scaffolding the connection string by using the Name= syntax to read it from configuration - see https://go.microsoft.com/fwlink/?linkid=2131148. For more guidance on storing connection strings, see https://go.microsoft.com/fwlink/?LinkId=723263.
        => optionsBuilder.UseSqlServer("Server=LAPTOP-8HFTBRPN;Database=PracMedic;Integrated Security=True;TrustServerCertificate=True");

    protected override void OnModelCreating(ModelBuilder modelBuilder)
    {
        modelBuilder.Entity<Anamneza>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("PK__Anamneza__3213E83F3E065E90");

            entity.ToTable("Anamneza");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.Gea).HasColumnName("GEA");
            entity.Property(e => e.Neockovat).HasColumnName("neockovat");
            entity.Property(e => e.Odmita).HasColumnName("odmita");
            entity.Property(e => e.OsobniAnamneza)
                .IsUnicode(false)
                .HasColumnName("osobniAnamneza");
            entity.Property(e => e.Pacient).HasColumnName("pacient");
            entity.Property(e => e.RodinnaAnamneza)
                .IsUnicode(false)
                .HasColumnName("rodinnaAnamneza");
            entity.Property(e => e.Tat).HasColumnName("TAT");
            entity.Property(e => e.Toks).HasColumnName("TOKS");
            entity.Property(e => e.Vydana).HasColumnName("vydana");

            entity.HasOne(d => d.PacientNavigation).WithMany(p => p.Anamnezas).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Pacient)
                .HasConstraintName("FK__Anamneza__pacien__6EF57B66");
        });

        modelBuilder.Entity<Dekur>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("PK__Dekurs__3213E83F0181C9D5");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.AktDekurs)
                .IsUnicode(false)
                .HasColumnName("aktDekurs");
            entity.Property(e => e.AktualniDg)
                .HasMaxLength(5)
                .IsUnicode(false)
                .HasColumnName("AktualniDG");
            entity.Property(e => e.MinDekurs)
                .IsUnicode(false)
                .HasColumnName("minDekurs");
            entity.Property(e => e.Pacient).HasColumnName("pacient");

            entity.HasOne(d => d.PacientNavigation).WithMany(p => p.DekursNavigation).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Pacient)
                .HasConstraintName("FK__Dekurs__pacient__6E01572D");
        });

        modelBuilder.Entity<Doktor>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("PK__Doktor__3213E83FC45CD96A");

            entity.ToTable("Doktor");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.CisloLekare)
                .HasMaxLength(20)
                .IsUnicode(false)
                .HasColumnName("cisloLekare");
            entity.Property(e => e.CisloPopisne)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("cisloPopisne");
            entity.Property(e => e.DatumNarozeni).HasColumnName("datumNarozeni");
            entity.Property(e => e.Email)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("email");
            entity.Property(e => e.HistorieLeku).HasColumnName("historieLeku");
            entity.Property(e => e.Jmeno)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("jmeno");
            entity.Property(e => e.Leky).HasColumnName("leky");
            entity.Property(e => e.Mesto)
                .HasMaxLength(40)
                .IsUnicode(false)
                .HasColumnName("mesto");
            entity.Property(e => e.Pracoviste).HasColumnName("pracoviste");
            entity.Property(e => e.PrihlHeslo)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("prihlHeslo");
            entity.Property(e => e.PrihlJmeno)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("prihlJmeno");
            entity.Property(e => e.Prijmeni)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("prijmeni");
            entity.Property(e => e.Psc)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("psc");
            entity.Property(e => e.TelefonniCislo)
                .HasMaxLength(25)
                .IsUnicode(false)
                .HasColumnName("telefonniCislo");
            entity.Property(e => e.TypUctu)
                .HasMaxLength(20)
                .IsUnicode(false)
                .HasColumnName("typUctu");
            entity.Property(e => e.Ulice)
                .HasMaxLength(60)
                .IsUnicode(false)
                .HasColumnName("ulice");

            entity.HasOne(d => d.HistorieLekuNavigation).WithMany(p => p.Doktors).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.HistorieLeku)
                .HasConstraintName("FK__Doktor__historie__4F7CD00D");

            entity.HasOne(d => d.LekyNavigation).WithMany(p => p.Doktors).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Leky)
                .HasConstraintName("FK__Doktor__leky__4E88ABD4");

            entity.HasOne(d => d.PracovisteNavigation).WithMany(p => p.Doktors).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Pracoviste)
                .HasConstraintName("FK__Doktor__pracovis__4D94879B");
        });

        modelBuilder.Entity<HistorieLeku>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("PK__Historie__3213E83F5FBD2A76");

            entity.ToTable("HistorieLeku");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.Datum).HasColumnName("datum");
            entity.Property(e => e.Nazev)
                .HasMaxLength(70)
                .IsUnicode(false)
                .HasColumnName("nazev");
        });

        modelBuilder.Entity<HistorieReceptu>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("PK__Historie__3213E83FC1949DBE");

            entity.ToTable("HistorieReceptu");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.VystaveniReceptu).HasColumnName("vystaveniReceptu");

            entity.HasOne(d => d.VystaveniReceptuNavigation).WithMany(p => p.HistorieReceptus).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.VystaveniReceptu)
                .HasConstraintName("FK__HistorieR__vysta__5070F446");
        });

        modelBuilder.Entity<Leky>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("PK__Leky__3213E83FE90B9302");

            entity.ToTable("Leky");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.Baleni)
                .HasMaxLength(70)
                .IsUnicode(false)
                .HasColumnName("baleni");
            entity.Property(e => e.Cena)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("cena");
            entity.Property(e => e.Doplatek)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("doplatek");
            entity.Property(e => e.Kod).HasColumnName("kod");
            entity.Property(e => e.Nazev)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("nazev");
            entity.Property(e => e.Omezeni)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("omezeni");
        });

        modelBuilder.Entity<Neschopenka>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("PK__Neschope__3213E83FD25CD4E5");

            entity.ToTable("Neschopenka");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.AktivovaniKodu).HasColumnName("aktivovaniKodu");
            entity.Property(e => e.Diagnoza)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("diagnoza");
            entity.Property(e => e.Doktor).HasColumnName("doktor");
            entity.Property(e => e.DruhPacienta)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("druhPacienta");
            entity.Property(e => e.Icz)
                .HasMaxLength(20)
                .IsUnicode(false)
                .HasColumnName("icz");
            entity.Property(e => e.KodStatu)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("kodStatu");
            entity.Property(e => e.NeschopenDo).HasColumnName("neschopenDo");
            entity.Property(e => e.NeschopenOd).HasColumnName("neschopenOd");
            entity.Property(e => e.Odb)
                .HasMaxLength(15)
                .IsUnicode(false)
                .HasColumnName("odb");
            entity.Property(e => e.Pacient).HasColumnName("pacient");
            entity.Property(e => e.PozitiAlkoholu).HasColumnName("pozitiAlkoholu");
            entity.Property(e => e.Pracoviste).HasColumnName("pracoviste");
            entity.Property(e => e.PracovniUraz).HasColumnName("pracovniUraz");
            entity.Property(e => e.RodneCislo)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("rodneCislo");
            entity.Property(e => e.StatisZnackaNemoci)
                .HasMaxLength(5)
                .IsUnicode(false)
                .HasColumnName("statisZnackaNemoci");
            entity.Property(e => e.TiskPrukazuPraceNeschopnehoPojistence).HasColumnName("tiskPrukazuPraceNeschopnehoPojistence");
            entity.Property(e => e.TypPece)
                .HasMaxLength(20)
                .IsUnicode(false)
                .HasColumnName("typPece");
            entity.Property(e => e.Uraz).HasColumnName("uraz");
            entity.Property(e => e.UrazZavinJinOsobou).HasColumnName("urazZavinJinOsobou");
            entity.Property(e => e.Vystaven).HasColumnName("vystaven");
            entity.Property(e => e.VystaveniProViceZamestnavatelu).HasColumnName("vystaveniProViceZamestnavatelu");
            entity.Property(e => e.VystavenoDne).HasColumnName("vystavenoDne");

            entity.HasOne(d => d.DoktorNavigation).WithMany(p => p.Neschopenkas).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Doktor)
                .HasConstraintName("FK__Neschopen__dokto__534D60F1");

            entity.HasOne(d => d.PacientNavigation).WithMany(p => p.Neschopenkas).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Pacient)
                .HasConstraintName("FK__Neschopen__pacie__52593CB8");

            entity.HasOne(d => d.PracovisteNavigation).WithMany(p => p.Neschopenkas).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Pracoviste)
                .HasConstraintName("FK__Neschopen__praco__5165187F");
        });

        modelBuilder.Entity<Objednani>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("PK__Objednan__3213E83F48CD3E07");

            entity.ToTable("Objednani");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.DatumObjednani).HasColumnName("datumObjednani");
            entity.Property(e => e.Pacient).HasColumnName("pacient");

            entity.HasOne(d => d.PacientNavigation).WithMany(p => p.Objednanis).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Pacient)
                .HasConstraintName("FK__Objednani__pacie__5441852A");
        });

        modelBuilder.Entity<Ockovani>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("PK__Ockovani__3213E83F1A4D9969");

            entity.ToTable("Ockovani");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.CestaPodani)
                .HasMaxLength(25)
                .IsUnicode(false)
                .HasColumnName("cestaPodani");
            entity.Property(e => e.Expirace).HasColumnName("expirace");
            entity.Property(e => e.MistoPodani)
                .HasMaxLength(25)
                .IsUnicode(false)
                .HasColumnName("mistoPodani");
            entity.Property(e => e.Mnozstvi)
                .HasMaxLength(2)
                .IsUnicode(false)
                .HasColumnName("mnozstvi");
            entity.Property(e => e.Nazev)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("nazev");
            entity.Property(e => e.Onemocneni)
                .IsUnicode(false)
                .HasColumnName("onemocneni");
            entity.Property(e => e.Pacient).HasColumnName("pacient");
            entity.Property(e => e.Poznamka)
                .HasMaxLength(100)
                .IsUnicode(false)
                .HasColumnName("poznamka");
            entity.Property(e => e.Sarze)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("sarze");
            entity.Property(e => e.TypDavky)
                .HasMaxLength(25)
                .IsUnicode(false)
                .HasColumnName("typDavky");

            entity.HasOne(d => d.PacientNavigation).WithMany(p => p.Ockovanis).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Pacient)
                .HasConstraintName("FK__Ockovani__pacien__6FE99F9F");
        });

        modelBuilder.Entity<Pacient>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("PK__Pacient__3213E83F41902932");

            entity.ToTable("Pacient");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.Anamneza).HasColumnName("anamneza");
            entity.Property(e => e.CisloPopisne)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("cisloPopisne");
            entity.Property(e => e.CisloPrukazu)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("cisloPrukazu");
            entity.Property(e => e.DatumNarozeni).HasColumnName("datumNarozeni");
            entity.Property(e => e.Dekurs).HasColumnName("dekurs");
            entity.Property(e => e.DruhPece)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("druhPece");
            entity.Property(e => e.DruhPojisteni)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("druhPojisteni");
            entity.Property(e => e.Ecp)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("ecp");
            entity.Property(e => e.Email)
                .HasMaxLength(100)
                .IsUnicode(false)
                .HasColumnName("email");
            entity.Property(e => e.Firma)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("firma");
            entity.Property(e => e.Gdpr).HasColumnName("gdpr");
            entity.Property(e => e.Ico)
                .HasMaxLength(20)
                .IsUnicode(false)
                .HasColumnName("ico");
            entity.Property(e => e.Jmeno)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("jmeno");
            entity.Property(e => e.Mesto)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("mesto");
            entity.Property(e => e.Narodnost)
                .HasMaxLength(4)
                .IsUnicode(false)
                .HasColumnName("narodnost");
            entity.Property(e => e.Ockovani).HasColumnName("ockovani");
            entity.Property(e => e.Okres)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("okres");
            entity.Property(e => e.Pohlavi)
                .HasMaxLength(2)
                .IsUnicode(false)
                .HasColumnName("pohlavi");
            entity.Property(e => e.PojisteniOd).HasColumnName("pojisteniOd");
            entity.Property(e => e.Pojistovna)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("pojistovna");
            entity.Property(e => e.Poschodi)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("poschodi");
            entity.Property(e => e.Poznamka)
                .IsUnicode(false)
                .HasColumnName("poznamka");
            entity.Property(e => e.Prijmeni)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("prijmeni");
            entity.Property(e => e.Profese)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("profese");
            entity.Property(e => e.Psc)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("psc");
            entity.Property(e => e.RegistrovanOd).HasColumnName("registrovanOd");
            entity.Property(e => e.RodneCislo)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("rodneCislo");
            entity.Property(e => e.RodnePrijmeni)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("rodnePrijmeni");
            entity.Property(e => e.TelCislo)
                .HasMaxLength(25)
                .IsUnicode(false)
                .HasColumnName("telCislo");
            entity.Property(e => e.TitulPred)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("titulPred");
            entity.Property(e => e.TitulZa)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("titulZa");
            entity.Property(e => e.Ulice)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("ulice");
            entity.Property(e => e.VystaveniReceptu).HasColumnName("vystaveniReceptu");
            entity.Property(e => e.ZamMesto)
                .HasMaxLength(50)
                .IsUnicode(false);
            entity.Property(e => e.ZamPsc)
                .HasMaxLength(30)
                .IsUnicode(false);
            entity.Property(e => e.ZamUlice)
                .HasMaxLength(50)
                .IsUnicode(false);
            entity.Property(e => e.ZamcisloPopisne)
                .HasMaxLength(30)
                .IsUnicode(false);

            entity.HasOne(d => d.AnamnezaNavigation).WithMany(p => p.Pacients).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Anamneza)
                .HasConstraintName("FK__Pacient__anamnez__66603565");

            entity.HasOne(d => d.Dekurs1).WithMany(p => p.Pacients).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Dekurs)
                .HasConstraintName("FK__Pacient__dekurs__60A75C0F");

            entity.HasOne(d => d.OckovaniNavigation).WithMany(p => p.Pacients).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Ockovani)
                .HasConstraintName("FK__Pacient__ockovan__628FA481");

            entity.HasOne(d => d.VystaveniReceptuNavigation).WithMany(p => p.Pacients).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.VystaveniReceptu)
                .HasConstraintName("FK__Pacient__vystave__5535A963");
        });

        modelBuilder.Entity<Pracoviste>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("PK__Pracovis__3213E83F7600F0DE");

            entity.ToTable("Pracoviste");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.CisloPopisne)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("cisloPopisne");
            entity.Property(e => e.Mesto)
                .HasMaxLength(40)
                .IsUnicode(false)
                .HasColumnName("mesto");
            entity.Property(e => e.Pracoviste1)
                .HasMaxLength(30)
                .IsUnicode(false)
                .HasColumnName("pracoviste");
            entity.Property(e => e.Psc)
                .HasMaxLength(10)
                .IsUnicode(false)
                .HasColumnName("psc");
            entity.Property(e => e.Ulice)
                .HasMaxLength(60)
                .IsUnicode(false)
                .HasColumnName("ulice");
        });

        modelBuilder.Entity<VystaveniReceptu>(entity =>
        {
            entity.HasKey(e => e.Id).HasName("PK__Vystaven__3213E83F9C1F78AC");

            entity.ToTable("VystaveniReceptu");

            entity.Property(e => e.Id).HasColumnName("id");
            entity.Property(e => e.Akutni).HasColumnName("akutni");
            entity.Property(e => e.DatumPredpisu).HasColumnName("datumPredpisu");
            entity.Property(e => e.Davkovani)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("davkovani");
            entity.Property(e => e.Dg)
                .HasMaxLength(15)
                .IsUnicode(false)
                .HasColumnName("dg");
            entity.Property(e => e.Doktor).HasColumnName("doktor");
            entity.Property(e => e.Formular)
                .HasMaxLength(15)
                .IsUnicode(false)
                .HasColumnName("formular");
            entity.Property(e => e.M)
                .HasMaxLength(20)
                .IsUnicode(false);
            entity.Property(e => e.Notifikace)
                .HasMaxLength(15)
                .IsUnicode(false)
                .HasColumnName("notifikace");
            entity.Property(e => e.OpakRecept).HasColumnName("opakRecept");
            entity.Property(e => e.PlatnostDo).HasColumnName("platnostDo");
            entity.Property(e => e.PocetBaleni)
                .HasMaxLength(3)
                .IsUnicode(false)
                .HasColumnName("pocetBaleni");
            entity.Property(e => e.Poznamka)
                .IsUnicode(false)
                .HasColumnName("poznamka");
            entity.Property(e => e.Preshranicni).HasColumnName("preshranicni");
            entity.Property(e => e.Rodina).HasColumnName("rodina");
            entity.Property(e => e.TelCislo)
                .HasMaxLength(15)
                .IsUnicode(false)
                .HasColumnName("telCislo");
            entity.Property(e => e.Uhrada)
                .HasMaxLength(15)
                .IsUnicode(false)
                .HasColumnName("uhrada");
            entity.Property(e => e.UpozorneniLekare)
                .HasMaxLength(15)
                .IsUnicode(false)
                .HasColumnName("upozorneniLekare");
            entity.Property(e => e.Ztotozneni)
                .HasMaxLength(50)
                .IsUnicode(false)
                .HasColumnName("ztotozneni");

            entity.HasOne(d => d.DoktorNavigation).WithMany(p => p.VystaveniReceptus).OnDelete(DeleteBehavior.Cascade)
                .HasForeignKey(d => d.Doktor)
                .HasConstraintName("FK__Vystaveni__dokto__4CA06362");
        });

        OnModelCreatingPartial(modelBuilder);
    }

    partial void OnModelCreatingPartial(ModelBuilder modelBuilder);
}
